Module commands

Module commands 

Re-exports

pub use list::list;

Modules

follow
flake-edit follow and flake-edit add-follow: declare or deduplicate inputs.<id>.follows edges.
list
flake-edit list: render the input set in one of the supported formats.

Structs

UriOptions
URI rewriting options that apply to both add and change.

Functions

add
change
config
pin
remove
unpin
update