split_quoted_path

Function split_quoted_path 

pub fn split_quoted_path(s: &str) -> Option<(&str, &str)>
Split an input path at the first . that is outside double quotes.

Nix attributes containing dots must be quoted (e.g. "hls-1.10"). A naive split_once('.') would split inside the quotes, so we skip any dot that appears between an opening and closing ".

Examples: "hls-1.10".nixpkgs -> ("hls-1.10", "nixpkgs") crane.nixpkgs -> ("crane", "nixpkgs") "hls-1.10" -> None nixpkgs -> None