pub enum Input {
Direct(String),
Indirect(Option<AttrPath>),
}Expand description
Reference from a node’s inputs map.
Lockfile shape:
"name"is a direct reference to another node, parsed asSelf::Direct.["a", "b", ...]is a follows path with a target, parsed asIndirect(Some(path)).[]is a follows declaration with no target (Nix emits this when an upstream chain has overridden the input to nothing, e.g. a lockfile whose sourceflake.nixcarriesnix.inputs.flake-compat.follows = "";), parsed asIndirect(None).
Variants